diff --git a/src/backend/access/hash/hashfunc.c b/src/backend/access/hash/hashfunc.c
index a2ad8df11f..e318777700 100644
--- a/src/backend/access/hash/hashfunc.c
+++ b/src/backend/access/hash/hashfunc.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/hash/hashfunc.c,v 1.20 1999/11/07 23:07:49 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/hash/hashfunc.c,v 1.21 2000/01/10 16:13:10 momjian Exp $
  *
  * NOTES
  *	  These functions are stored in pg_amproc.	For each operator class
@@ -140,7 +140,7 @@ hashoid(Oid key)
 }
 
 uint32
-hashoid8(Oid *key)
+hashoidvector(Oid *key)
 {
 	int			i;
 	uint32		result = 0;
diff --git a/src/backend/access/nbtree/nbtcompare.c b/src/backend/access/nbtree/nbtcompare.c
index 0fc6d4ca69..57c3f981a3 100644
--- a/src/backend/access/nbtree/nbtcompare.c
+++ b/src/backend/access/nbtree/nbtcompare.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/nbtree/nbtcompare.c,v 1.28 1999/11/07 23:07:56 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/nbtree/nbtcompare.c,v 1.29 2000/01/10 16:13:10 momjian Exp $
  *
  *	NOTES
  *		These functions are stored in pg_amproc.  For each operator class
@@ -94,7 +94,7 @@ btoidcmp(Oid a, Oid b)
 }
 
 int32
-btoid8cmp(Oid *a, Oid *b)
+btoidvectorcmp(Oid *a, Oid *b)
 {
 	int			i;
 
diff --git a/src/backend/bootstrap/bootstrap.c b/src/backend/bootstrap/bootstrap.c
index 3ae935339c..12dd3df7b0 100644
--- a/src/backend/bootstrap/bootstrap.c
+++ b/src/backend/bootstrap/bootstrap.c
@@ -7,7 +7,7 @@
  * Copyright (c) 1994, Regents of the University of California
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/bootstrap/bootstrap.c,v 1.74 1999/12/20 10:40:39 wieck Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/bootstrap/bootstrap.c,v 1.75 2000/01/10 16:13:11 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -109,7 +109,7 @@ static struct typinfo Procid[] = {
 	{"dummy", 20, 0, 16, 0, 0},
 /*	  { "dt",		  20,	 0,  4, F_DTIN,			F_DTOUT}, */
 	{"int2", 21, 0, 2, F_INT2IN, F_INT2OUT},
-	{"int28", 22, 0, 16, F_INT28IN, F_INT28OUT},
+	{"int2vector", 22, 0, 16, F_INT2VECTORIN, F_INT2VECTOROUT},
 	{"int4", 23, 0, 4, F_INT4IN, F_INT4OUT},
 	{"regproc", 24, 0, 4, F_REGPROCIN, F_REGPROCOUT},
 	{"text", 25, 0, -1, F_TEXTIN, F_TEXTOUT},
@@ -117,7 +117,7 @@ static struct typinfo Procid[] = {
 	{"tid", 27, 0, 6, F_TIDIN, F_TIDOUT},
 	{"xid", 28, 0, 5, F_XIDIN, F_XIDOUT},
 	{"iid", 29, 0, 1, F_CIDIN, F_CIDOUT},
-	{"oid8", 30, 0, 32, F_OID8IN, F_OID8OUT},
+	{"oidvector", 30, 0, 32, F_OIDVECTORIN, F_OIDVECTOROUT},
 	{"smgr", 210, 0, 2, F_SMGRIN, F_SMGROUT},
 	{"_int4", 1007, 23, -1, F_ARRAY_IN, F_ARRAY_OUT},
 	{"_aclitem", 1034, 1033, -1, F_ARRAY_IN, F_ARRAY_OUT}
diff --git a/src/backend/catalog/indexing.c b/src/backend/catalog/indexing.c
index d7baec4eae..97e15d5d1d 100644
--- a/src/backend/catalog/indexing.c
+++ b/src/backend/catalog/indexing.c
@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/catalog/indexing.c,v 1.55 1999/12/30 05:04:55 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/catalog/indexing.c,v 1.56 2000/01/10 16:13:12 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -763,7 +763,7 @@ ProcedureNameIndexScan(Relation heapRelation,
 	ScanKeyEntryInitialize(&skey[2],
 						   (bits16) 0x0,
 						   (AttrNumber) 3,
-						   (RegProcedure) F_OID8EQ,
+						   (RegProcedure) F_OIDVECTOREQ,
 						   PointerGetDatum(argTypes));
 
 	idesc = index_openr(ProcedureNameIndex);
diff --git a/src/backend/tcop/fastpath.c b/src/backend/tcop/fastpath.c
index d8f3009afb..8a921ac906 100644
--- a/src/backend/tcop/fastpath.c
+++ b/src/backend/tcop/fastpath.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/tcop/fastpath.c,v 1.31 1999/11/22 17:56:26 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/tcop/fastpath.c,v 1.32 2000/01/10 16:13:13 momjian Exp $
  *
  * NOTES
  *	  This cruft is the server side of PQfn.
@@ -181,7 +181,7 @@ valid_fp_info(Oid func_id, struct fp_info * fip)
 static void
 update_fp_info(Oid func_id, struct fp_info * fip)
 {
-	Oid		   *argtypes;		/* an oid8 */
+	Oid		   *argtypes;		/* an oidvector */
 	Oid			rettype;
 	HeapTuple	func_htp,
 				type_htp;
diff --git a/src/backend/utils/adt/int8.c b/src/backend/utils/adt/int8.c
index a3132b408e..7b444df185 100644
--- a/src/backend/utils/adt/int8.c
+++ b/src/backend/utils/adt/int8.c
@@ -519,7 +519,7 @@ int84(int64 *val)
 
 #if NOT_USED
 int64 *
-int28		(int16 val)
+int2vector		(int16 val)
 {
 	int64	   *result;
 
@@ -528,7 +528,7 @@ int28		(int16 val)
 	*result = val;
 
 	return result;
-}	/* int28() */
+}	/* int2vector() */
 
 int16
 int82(int64 *val)
diff --git a/src/backend/utils/adt/regproc.c b/src/backend/utils/adt/regproc.c
index dffedd5f7f..d15c7a4393 100644
--- a/src/backend/utils/adt/regproc.c
+++ b/src/backend/utils/adt/regproc.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/regproc.c,v 1.47 1999/12/30 05:05:07 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/regproc.c,v 1.48 2000/01/10 16:13:14 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -233,7 +233,7 @@ regprocout(RegProcedure proid)
  *		int8typeout			- converts int8 type oids to "typname" list
  */
 text *
-oid8types(Oid *oidArray)
+oidvectortypes(Oid *oidArray)
 {
 	HeapTuple	typetup;
 	text	   *result;
diff --git a/src/backend/utils/cache/catcache.c b/src/backend/utils/cache/catcache.c
index e061e8feae..c9f26f38ad 100644
--- a/src/backend/utils/cache/catcache.c
+++ b/src/backend/utils/cache/catcache.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/cache/catcache.c,v 1.55 1999/12/16 22:19:54 wieck Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/cache/catcache.c,v 1.56 2000/01/10 16:13:15 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -70,7 +70,7 @@ GlobalMemory CacheCxt;			/* context in which caches are allocated */
 static long eqproc[] = {
 	F_BOOLEQ, 0l, F_CHAREQ, F_NAMEEQ, 0l,
 	F_INT2EQ, F_KEYFIRSTEQ, F_INT4EQ, 0l, F_TEXTEQ,
-	F_OIDEQ, 0l, 0l, 0l, F_OID8EQ
+	F_OIDEQ, 0l, 0l, 0l, F_OIDVECTOREQ
 };
 
 #define EQPROC(SYSTEMTYPEOID)	eqproc[(SYSTEMTYPEOID)-16]
@@ -191,14 +191,14 @@ CatalogCacheInitializeCache(struct catcache * cache,
 
 			/*
 			 * Yoiks.  The implementation of the hashing code and the
-			 * implementation of int28's are at loggerheads.  The right
-			 * thing to do is to throw out the implementation of int28's
+			 * implementation of int2vector's are at loggerheads.  The right
+			 * thing to do is to throw out the implementation of int2vector's
 			 * altogether; until that happens, we do the right thing here
 			 * to guarantee that the hash key generator doesn't try to
 			 * dereference an int2 by mistake.
 			 */
 
-			if (tupdesc->attrs[cache->cc_key[i] - 1]->atttypid == INT28OID)
+			if (tupdesc->attrs[cache->cc_key[i] - 1]->atttypid == INT2VECTOROID)
 				cache->cc_klen[i] = sizeof(short);
 			else
 				cache->cc_klen[i] = tupdesc->attrs[cache->cc_key[i] - 1]->attlen;
@@ -851,7 +851,7 @@ SearchSelfReferences(struct catcache * cache)
 		{
 			HeapScanDesc	sd;
 			MemoryContext	oldcxt;
-	
+
 			if (!CacheCxt)
 				CacheCxt = CreateGlobalMemory("Cache");
 			rel = heap_open(cache->relationId, AccessShareLock);
@@ -872,7 +872,7 @@ SearchSelfReferences(struct catcache * cache)
 		/* bootstrapping this requires preloading a range of rows. bjm */
 		static HeapTuple	operatorSelfTuple[MAX_OIDCMP-MIN_OIDCMP+1];
 		Oid					lookup_oid = (Oid)cache->cc_skey[0].sk_argument;
-		
+
 		if (lookup_oid < MIN_OIDCMP || lookup_oid > MAX_OIDCMP)
 			return (HeapTuple)0;
 
@@ -880,7 +880,7 @@ SearchSelfReferences(struct catcache * cache)
 		{
 			HeapScanDesc	sd;
 			MemoryContext	oldcxt;
-	
+
 			if (!CacheCxt)
 				CacheCxt = CreateGlobalMemory("Cache");
 			rel = heap_open(cache->relationId, AccessShareLock);
diff --git a/src/bin/pg_dump/pg_dump.c b/src/bin/pg_dump/pg_dump.c
index 3eecd0b6cf..3bfe2f0ab6 100644
--- a/src/bin/pg_dump/pg_dump.c
+++ b/src/bin/pg_dump/pg_dump.c
@@ -21,7 +21,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/bin/pg_dump/pg_dump.c,v 1.129 1999/12/27 18:21:07 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/bin/pg_dump/pg_dump.c,v 1.130 2000/01/10 16:13:16 momjian Exp $
  *
  * Modifications - 6/10/96 - dave@bensoft.com - version 1.13.dhb
  *
@@ -1770,7 +1770,6 @@ getTables(int *numTables, FuncInfo *finfo, int numFuncs)
 				for (findx = 0; findx < tgnargs; findx++)
 				{
 					const char	   *s;
-                    char           *d;
 
 					for (p = tgargs;;)
 					{
diff --git a/src/bin/psql/describe.c b/src/bin/psql/describe.c
index 1b6314fdc5..728866fa3c 100644
--- a/src/bin/psql/describe.c
+++ b/src/bin/psql/describe.c
@@ -118,7 +118,7 @@ describeFunctions(const char *name, PsqlSettings *pset, bool verbose, bool desc)
 	 */
 	strcpy(buf,
 	   "SELECT t.typname as \"Result\", p.proname as \"Function\",\n"
-		   "       oid8types(p.proargtypes) as \"Arguments\"");
+		   "       oidvectortypes(p.proargtypes) as \"Arguments\"");
     if (verbose)
 	strcat(buf, ",\n       u.usename as \"Owner\", l.lanname as \"Language\", p.prosrc as \"Source\"");
 	if (desc)
@@ -127,12 +127,12 @@ describeFunctions(const char *name, PsqlSettings *pset, bool verbose, bool desc)
     if (!verbose)
 	strcat(buf,
 	       "\nFROM pg_proc p, pg_type t\n"
-	       "WHERE p.prorettype = t.oid and (pronargs = 0 or oid8types(p.proargtypes) != '')\n");
+	       "WHERE p.prorettype = t.oid and (pronargs = 0 or oidvectortypes(p.proargtypes) != '')\n");
     else
 	strcat(buf,
 	       "\nFROM pg_proc p, pg_type t, pg_language l, pg_user u\n"
 	       "WHERE p.prorettype = t.oid AND p.prolang = l.oid AND p.proowner = u.usesysid\n"
-	       "  AND (pronargs = 0 or oid8types(p.proargtypes) != '')\n");
+	       "  AND (pronargs = 0 or oidvectortypes(p.proargtypes) != '')\n");
 
 	if (name)
 	{
@@ -427,7 +427,7 @@ objectDescription(const char *object, PsqlSettings *pset)
 	strcat(descbuf, "\nUNION ALL\n\n");
 	strcat(descbuf, "SELECT DISTINCT p.proname as \"Name\", 'function'::text as \"What\", d.description as \"Description\"\n"
 		   "FROM pg_proc p, pg_description d\n"
-		   "WHERE p.oid = d.objoid AND (p.pronargs = 0 or oid8types(p.proargtypes) != '')\n");
+		   "WHERE p.oid = d.objoid AND (p.pronargs = 0 or oidvectortypes(p.proargtypes) != '')\n");
 	if (object)
 	{
 		strcat(descbuf, "  AND p.proname ~* '");
diff --git a/src/include/access/hash.h b/src/include/access/hash.h
index ea94f5cc9e..d6e08b4fec 100644
--- a/src/include/access/hash.h
+++ b/src/include/access/hash.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: hash.h,v 1.28 1999/07/19 07:07:27 momjian Exp $
+ * $Id: hash.h,v 1.29 2000/01/10 16:13:19 momjian Exp $
  *
  * NOTES
  *		modeled after Margo Seltzer's hash implementation for unix.
@@ -268,7 +268,7 @@ extern uint32 hashint8(int64 *key);
 extern uint32 hashfloat4(float32 keyp);
 extern uint32 hashfloat8(float64 keyp);
 extern uint32 hashoid(Oid key);
-extern uint32 hashoid8(Oid *key);
+extern uint32 hashoidvector(Oid *key);
 extern uint32 hashchar(char key);
 extern uint32 hashtext(struct varlena * key);
 extern uint32 hashname(NameData *n);
diff --git a/src/include/catalog/catversion.h b/src/include/catalog/catversion.h
index 62244f88a4..c4d3872e77 100644
--- a/src/include/catalog/catversion.h
+++ b/src/include/catalog/catversion.h
@@ -36,7 +36,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: catversion.h,v 1.5 1999/12/13 01:27:07 tgl Exp $
+ * $Id: catversion.h,v 1.6 2000/01/10 16:13:20 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -51,6 +51,6 @@
  * catalog changes on the same day...)
  */
 
-#define CATALOG_VERSION_NO	199912121
+#define CATALOG_VERSION_NO	20000110
 
 #endif
diff --git a/src/include/catalog/indexing.h b/src/include/catalog/indexing.h
index d2cdc1a176..ff7a166f2e 100644
--- a/src/include/catalog/indexing.h
+++ b/src/include/catalog/indexing.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: indexing.h,v 1.32 1999/11/24 17:09:28 momjian Exp $
+ * $Id: indexing.h,v 1.33 2000/01/10 16:13:20 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -193,7 +193,7 @@ DECLARE_UNIQUE_INDEX(pg_opclass_name_index on pg_opclass using btree(opcname nam
 DECLARE_UNIQUE_INDEX(pg_operator_oid_index on pg_operator using btree(oid oid_ops));
 DECLARE_UNIQUE_INDEX(pg_operator_oprname_l_r_k_index on pg_operator using btree(oprname name_ops, oprleft oid_ops, oprright oid_ops, oprkind char_ops));
 DECLARE_UNIQUE_INDEX(pg_proc_oid_index on pg_proc using btree(oid oid_ops));
-DECLARE_UNIQUE_INDEX(pg_proc_proname_narg_type_index on pg_proc using btree(proname name_ops, pronargs int2_ops, proargtypes oid8_ops));
+DECLARE_UNIQUE_INDEX(pg_proc_proname_narg_type_index on pg_proc using btree(proname name_ops, pronargs int2_ops, proargtypes oidvector_ops));
 /* This following index is not used for a cache and is not unique */
 DECLARE_INDEX(pg_relcheck_rcrelid_index on pg_relcheck using btree(rcrelid oid_ops));
 DECLARE_UNIQUE_INDEX(pg_rewrite_oid_index on pg_rewrite using btree(oid oid_ops));
diff --git a/src/include/catalog/pg_amop.h b/src/include/catalog/pg_amop.h
index e2ee4b30cf..93ed1d4693 100644
--- a/src/include/catalog/pg_amop.h
+++ b/src/include/catalog/pg_amop.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_amop.h,v 1.26 1999/12/28 13:40:50 wieck Exp $
+ * $Id: pg_amop.h,v 1.27 2000/01/10 16:13:20 momjian Exp $
  *
  * NOTES
  *	 the genbki.sh script reads this file and generates .bki
@@ -188,7 +188,7 @@ DATA(insert OID = 0 (  403 427 612 4 btreesel btreenpage ));
 DATA(insert OID = 0 (  403 427 610 5 btreesel btreenpage ));
 
 /*
- *	nbtree oid8_ops
+ *	nbtree oidvector_ops
  */
 
 DATA(insert OID = 0 (  403 435	645 1 btreesel btreenpage ));
@@ -362,7 +362,7 @@ DATA(insert OID = 0 (  405	426   96 1 hashsel hashnpage ));
 DATA(insert OID = 0 (  405	754  410 1 hashsel hashnpage ));
 /* oid_ops */
 DATA(insert OID = 0 (  405	427  607 1 hashsel hashnpage ));
-/* oid8_ops */
+/* oidvector_ops */
 DATA(insert OID = 0 (  405	435  649 1 hashsel hashnpage ));
 /* float4_ops */
 DATA(insert OID = 0 (  405	428  620 1 hashsel hashnpage ));
diff --git a/src/include/catalog/pg_index.h b/src/include/catalog/pg_index.h
index 5ab3af31e5..52b112d3c5 100644
--- a/src/include/catalog/pg_index.h
+++ b/src/include/catalog/pg_index.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_index.h,v 1.13 2000/01/10 04:36:37 momjian Exp $
+ * $Id: pg_index.h,v 1.14 2000/01/10 16:13:20 momjian Exp $
  *
  * NOTES
  *	  the genbki.sh script reads this file and generates .bki
@@ -45,8 +45,8 @@ CATALOG(pg_index)
 	Oid			indrelid;
 	Oid			indproc;		/* registered procedure for functional
 								 * index */
-	int28		indkey;
-	oid8		indclass;
+	int2vector	indkey;
+	oidvector	indclass;
 	bool		indisclustered;
 	bool		indislossy;		/* do we fetch false tuples (lossy
 								 * compression)? */
diff --git a/src/include/catalog/pg_opclass.h b/src/include/catalog/pg_opclass.h
index deb13cc440..e64164b302 100644
--- a/src/include/catalog/pg_opclass.h
+++ b/src/include/catalog/pg_opclass.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_opclass.h,v 1.25 1999/12/28 13:40:50 wieck Exp $
+ * $Id: pg_opclass.h,v 1.26 2000/01/10 16:13:20 momjian Exp $
  *
  * NOTES
  *	  the genbki.sh script reads this file and generates .bki
@@ -89,7 +89,7 @@ DATA(insert OID =  433 (	bigbox_ops		603   ));
 DESCR("");
 DATA(insert OID =  434 (	poly_ops		604   ));
 DESCR("");
-DATA(insert OID =  435 (	oid8_ops		 30   ));
+DATA(insert OID =  435 (	oidvector_ops	 30   ));
 DESCR("");
 DATA(insert OID =  714 (	circle_ops		718   ));
 DESCR("");
diff --git a/src/include/catalog/pg_operator.h b/src/include/catalog/pg_operator.h
index c161bce8c1..6c7619be33 100644
--- a/src/include/catalog/pg_operator.h
+++ b/src/include/catalog/pg_operator.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_operator.h,v 1.63 1999/12/28 13:40:50 wieck Exp $
+ * $Id: pg_operator.h,v 1.64 2000/01/10 16:13:20 momjian Exp $
  *
  * NOTES
  *	  the genbki.sh script reads this file and generates .bki
@@ -282,12 +282,12 @@ DATA(insert OID = 611 (  "<="	   PGUID 0 b t f  26  26  16 612 610  0  0 int4le
 DATA(insert OID = 612 (  ">="	   PGUID 0 b t f  26  26  16 611 609  0  0 int4ge intgtsel intgtjoinsel ));
 #define MAX_OIDCMP 612 /* used by cache code */
 
-DATA(insert OID = 644 (  "<>"	   PGUID 0 b t f  30  30  16 644 649   0   0 oid8ne neqsel neqjoinsel ));
-DATA(insert OID = 645 (  "<"	   PGUID 0 b t f  30  30  16 646 648   0   0 oid8lt intltsel intltjoinsel ));
-DATA(insert OID = 646 (  ">"	   PGUID 0 b t f  30  30  16 645 647   0   0 oid8gt intgtsel intgtjoinsel ));
-DATA(insert OID = 647 (  "<="	   PGUID 0 b t f  30  30  16 648 646   0   0 oid8le intltsel intltjoinsel ));
-DATA(insert OID = 648 (  ">="	   PGUID 0 b t f  30  30  16 647 645   0   0 oid8ge intgtsel intgtjoinsel ));
-DATA(insert OID = 649 (  "="	   PGUID 0 b t t  30  30  16 649 644 645 645 oid8eq eqsel eqjoinsel ));
+DATA(insert OID = 644 (  "<>"	   PGUID 0 b t f  30  30  16 644 649   0   0 oidvectorne neqsel neqjoinsel ));
+DATA(insert OID = 645 (  "<"	   PGUID 0 b t f  30  30  16 646 648   0   0 oidvectorlt intltsel intltjoinsel ));
+DATA(insert OID = 646 (  ">"	   PGUID 0 b t f  30  30  16 645 647   0   0 oidvectorgt intgtsel intgtjoinsel ));
+DATA(insert OID = 647 (  "<="	   PGUID 0 b t f  30  30  16 648 646   0   0 oidvectorle intltsel intltjoinsel ));
+DATA(insert OID = 648 (  ">="	   PGUID 0 b t f  30  30  16 647 645   0   0 oidvectorge intgtsel intgtjoinsel ));
+DATA(insert OID = 649 (  "="	   PGUID 0 b t t  30  30  16 649 644 645 645 oidvectoreq eqsel eqjoinsel ));
 
 DATA(insert OID = 613 (  "<->"	   PGUID 0 b t f 600 628 701   0   0  0  0 dist_pl - - ));
 DATA(insert OID = 614 (  "<->"	   PGUID 0 b t f 600 601 701   0   0  0  0 dist_ps - - ));
diff --git a/src/include/catalog/pg_proc.h b/src/include/catalog/pg_proc.h
index abb03c76f8..32ef4bca2e 100644
--- a/src/include/catalog/pg_proc.h
+++ b/src/include/catalog/pg_proc.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_proc.h,v 1.111 2000/01/06 20:46:54 wieck Exp $
+ * $Id: pg_proc.h,v 1.112 2000/01/10 16:13:21 momjian Exp $
  *
  * NOTES
  *	  The script catalog/genbki.sh reads this file and generates .bki
@@ -47,7 +47,7 @@ CATALOG(pg_proc) BOOTSTRAP
 	int2		pronargs;
 	bool		proretset;
 	Oid			prorettype;
-	oid8		proargtypes;
+	oidvector	proargtypes;
 	int4		probyte_pct;
 	int4		properbyte_cpu;
 	int4		propercall_cpu;
@@ -116,9 +116,9 @@ DATA(insert OID =  38 (  int2in			   PGUID 11 f t t 1 f 21 "0" 100 0 0 100  int2
 DESCR("(internal)");
 DATA(insert OID =  39 (  int2out		   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  int2out - ));
 DESCR("(internal)");
-DATA(insert OID =  40 (  int28in		   PGUID 11 f t t 1 f 22 "0" 100 0 0 100  int28in - ));
+DATA(insert OID =  40 (  int2vectorin	   PGUID 11 f t t 1 f 22 "0" 100 0 0 100  int2vectorin - ));
 DESCR("(internal)");
-DATA(insert OID =  41 (  int28out		   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  int28out - ));
+DATA(insert OID =  41 (  int2vectorout	   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  int2vectorout - ));
 DESCR("(internal)");
 DATA(insert OID =  42 (  int4in			   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  int4in - ));
 DESCR("(internal)");
@@ -144,9 +144,9 @@ DATA(insert OID =  52 (  cidin			   PGUID 11 f t t 1 f 29 "0" 100 0 0 100  cidin
 DESCR("(internal)");
 DATA(insert OID =  53 (  cidout			   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  cidout - ));
 DESCR("(internal)");
-DATA(insert OID =  54 (  oid8in			   PGUID 11 f t t 1 f 30 "0" 100 0 0 100  oid8in - ));
+DATA(insert OID =  54 (  oidvectorin	   PGUID 11 f t t 1 f 30 "0" 100 0 0 100  oidvectorin - ));
 DESCR("(internal)");
-DATA(insert OID =  55 (  oid8out		   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  oid8out - ));
+DATA(insert OID =  55 (  oidvectorout	   PGUID 11 f t t 1 f 23 "0" 100 0 0 100  oidvectorout - ));
 DESCR("(internal)");
 DATA(insert OID =  56 (  boollt			   PGUID 11 f t t 2 f 16 "16 16" 100 0 0 100  boollt - ));
 DESCR("less-than");
@@ -750,7 +750,7 @@ DATA(insert OID = 355 (  btfloat8cmp	   PGUID 11 f t t 2 f 23 "701 701" 100 0 0
 DESCR("btree less-equal-greater");
 DATA(insert OID = 356 (  btoidcmp		   PGUID 11 f t t 2 f 23 "26 26" 100 0 0 100  btoidcmp - ));
 DESCR("btree less-equal-greater");
-DATA(insert OID = 404 (  btoid8cmp		   PGUID 11 f t t 2 f 23 "30 30" 100 0 0 100  btoid8cmp - ));
+DATA(insert OID = 404 (  btoidvectorcmp	   PGUID 11 f t t 2 f 23 "30 30" 100 0 0 100  btoidvectorcmp - ));
 DESCR("btree less-equal-greater");
 DATA(insert OID = 357 (  btabstimecmp	   PGUID 11 f t f 2 f 23 "702 702" 100 0 0 100	btabstimecmp - ));
 DESCR("btree less-equal-greater");
@@ -840,7 +840,7 @@ DATA(insert OID = 455 (  hashname		   PGUID 11 f t t 1 f 23 "19" 100 0 0 100  ha
 DESCR("hash");
 DATA(insert OID = 456 (  hashtext		   PGUID 11 f t t 1 f 23 "25" 100 0 0 100  hashtext - ));
 DESCR("hash");
-DATA(insert OID = 457 (  hashoid8		   PGUID 11 f t t 1 f 23 "30" 100 0 0 100  hashoid8 - ));
+DATA(insert OID = 457 (  hashoidvector	   PGUID 11 f t t 1 f 23 "30" 100 0 0 100  hashoidvector - ));
 DESCR("hash");
 DATA(insert OID = 458 (  text_larger	   PGUID 11 f t t 2 f 25 "25 25" 100 0 0 100  text_larger - ));
 DESCR("larger of two");
@@ -926,17 +926,17 @@ DESCR("truncate varchar()");
 
 DATA(insert OID = 676 (  mktinterval	   PGUID 11 f t f 2 f 704 "702 702" 100 0 0 100 mktinterval - ));
 DESCR("convert to interval");
-DATA(insert OID = 619 (  oid8ne			   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oid8ne - ));
+DATA(insert OID = 619 (  oidvectorne	   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oidvectorne - ));
 DESCR("less-than");
-DATA(insert OID = 677 (  oid8lt			   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oid8lt - ));
+DATA(insert OID = 677 (  oidvectorlt	   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oidvectorlt - ));
 DESCR("less-than");
-DATA(insert OID = 678 (  oid8le			   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oid8le - ));
+DATA(insert OID = 678 (  oidvectorle	   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oidvectorle - ));
 DESCR("less-than-or-equal");
-DATA(insert OID = 679 (  oid8eq			   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oid8eq - ));
+DATA(insert OID = 679 (  oidvectoreq	   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oidvectoreq - ));
 DESCR("equal");
-DATA(insert OID = 680 (  oid8ge			   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oid8ge - ));
+DATA(insert OID = 680 (  oidvectorge	   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oidvectorge - ));
 DESCR("greater-than-or-equal");
-DATA(insert OID = 681 (  oid8gt			   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oid8gt - ));
+DATA(insert OID = 681 (  oidvectorgt	   PGUID 11 f t t 2 f 16 "30 30" 100 0 0 100  oidvectorgt - ));
 DESCR("greater-than");
 
 /* OIDS 700 - 799 */
@@ -1621,8 +1621,8 @@ DATA(insert OID = 1347 (  int4				 PGUID 11 f t t 1 f   23 "25" 100 0 0 100  tex
 DESCR("convert text to int4");
 DATA(insert OID = 1348 (  obj_description	 PGUID 14 f t f 1 f   25 "26" 100 0 0 100  "select description from pg_description where objoid = $1" - ));
 DESCR("get description for object id");
-DATA(insert OID = 1349 (  oid8types			 PGUID 11 f t f 1 f   25 "30" 100 0 0 100  oid8types - ));
-DESCR("print type names of oid8 field");
+DATA(insert OID = 1349 (  oidvectortypes	 PGUID 11 f t f 1 f   25 "30" 100 0 0 100  oidvectortypes - ));
+DESCR("print type names of oidvector field");
 
 DATA(insert OID = 1350 (  datetime			 PGUID 14 f t f 1 f 1184 "1184" 100 0 0 100  "select $1" - ));
 DESCR("convert (noop)");
diff --git a/src/include/catalog/pg_trigger.h b/src/include/catalog/pg_trigger.h
index be0633eb98..702cb9f238 100644
--- a/src/include/catalog/pg_trigger.h
+++ b/src/include/catalog/pg_trigger.h
@@ -41,7 +41,7 @@ CATALOG(pg_trigger) BOOTSTRAP
 	bool		tgdeferrable;	/* RI trigger is deferrable */
 	bool		tginitdeferred;	/* RI trigger is deferred initially */
 	int2		tgnargs;		/* # of extra arguments in tgargs */
-	int28		tgattr;			/* UPDATE of attr1, attr2 ... (NI) */
+	int2vector	tgattr;			/* UPDATE of attr1, attr2 ... (NI) */
 	bytea		tgargs;			/* first\000second\000tgnargs\000 */
 } FormData_pg_trigger;
 
diff --git a/src/include/postgres.h b/src/include/postgres.h
index 4c51ceea42..455b8f2329 100644
--- a/src/include/postgres.h
+++ b/src/include/postgres.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1995, Regents of the University of California
  *
- * $Id: postgres.h,v 1.33 2000/01/10 05:20:26 momjian Exp $
+ * $Id: postgres.h,v 1.34 2000/01/10 16:13:18 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -19,7 +19,7 @@
  *				Oid		   regproc	  RegProcedure
  *				aclitem
  *				struct varlena
- *				int28	  oid8
+ *				int2vector	  oidvector
  *				bytea	   text
  *				NameData   Name
  *
@@ -101,8 +101,8 @@ struct varlena
 typedef struct varlena bytea;
 typedef struct varlena text;
 
-typedef int2 int28[INDEX_MAX_KEYS];
-typedef Oid oid8[INDEX_MAX_KEYS];
+typedef int2 int2vector[INDEX_MAX_KEYS];
+typedef Oid oidvector[INDEX_MAX_KEYS];
 
 
 /*
diff --git a/src/include/utils/builtins.h b/src/include/utils/builtins.h
index eca5f42d33..2e8b9771a9 100644
--- a/src/include/utils/builtins.h
+++ b/src/include/utils/builtins.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: builtins.h,v 1.94 2000/01/06 20:47:01 wieck Exp $
+ * $Id: builtins.h,v 1.95 2000/01/10 16:13:22 momjian Exp $
  *
  * NOTES
  *	  This should normally only be included by fmgr.h.
@@ -67,8 +67,8 @@ extern text *char_text(int8 arg1);
 /* int.c */
 extern int32 int2in(char *num);
 extern char *int2out(int16 sh);
-extern int16 *int28in(char *shs);
-extern char *int28out(int16 *shs);
+extern int16 *int2vectorin(char *shs);
+extern char *int2vectorout(int16 *shs);
 extern int32 *int44in(char *input_string);
 extern char *int44out(int32 *an_array);
 extern int32 int4in(char *num);
@@ -174,7 +174,7 @@ extern int32 btint42cmp(int32 a, int16 b);
 extern int32 btfloat4cmp(float32 a, float32 b);
 extern int32 btfloat8cmp(float64 a, float64 b);
 extern int32 btoidcmp(Oid a, Oid b);
-extern int32 btoid8cmp(Oid *a, Oid *b);
+extern int32 btoidvectorcmp(Oid *a, Oid *b);
 extern int32 btabstimecmp(AbsoluteTime a, AbsoluteTime b);
 extern int32 btcharcmp(char a, char b);
 extern int32 btnamecmp(NameData *a, NameData *b);
@@ -340,18 +340,18 @@ extern bool int4notin(int32 not_in_arg, char *relation_and_attr);
 extern bool oidnotin(Oid the_oid, char *compare);
 
 /* oid.c */
-extern Oid *oid8in(char *oidString);
-extern char *oid8out(Oid *oidArray);
+extern Oid *oidvectorin(char *oidString);
+extern char *oidvectorout(Oid *oidArray);
 extern Oid	oidin(char *s);
 extern char *oidout(Oid o);
 extern bool oideq(Oid arg1, Oid arg2);
 extern bool oidne(Oid arg1, Oid arg2);
-extern bool oid8eq(Oid *arg1, Oid *arg2);
-extern bool oid8ne(Oid *arg1, Oid *arg2);
-extern bool oid8lt(Oid *arg1, Oid *arg2);
-extern bool oid8le(Oid *arg1, Oid *arg2);
-extern bool oid8ge(Oid *arg1, Oid *arg2);
-extern bool oid8gt(Oid *arg1, Oid *arg2);
+extern bool oidvectoreq(Oid *arg1, Oid *arg2);
+extern bool oidvectorne(Oid *arg1, Oid *arg2);
+extern bool oidvectorlt(Oid *arg1, Oid *arg2);
+extern bool oidvectorle(Oid *arg1, Oid *arg2);
+extern bool oidvectorge(Oid *arg1, Oid *arg2);
+extern bool oidvectorgt(Oid *arg1, Oid *arg2);
 extern bool oideqint4(Oid arg1, int32 arg2);
 extern bool int4eqoid(int32 arg1, Oid arg2);
 extern text *oid_text(Oid arg1);
@@ -371,7 +371,7 @@ extern bool texticregexne(struct varlena * s, struct varlena * p);
 /* regproc.c */
 extern int32 regprocin(char *pro_name_and_oid);
 extern char *regprocout(RegProcedure proid);
-extern text *oid8types(Oid *oidArray);
+extern text *oidvectortypes(Oid *oidArray);
 extern Oid	regproctooid(RegProcedure rp);
 
 /* define macro to replace mixed-case function call - tgl 97/04/27 */
diff --git a/src/include/utils/int8.h b/src/include/utils/int8.h
index 3412cabd2e..b55cecf847 100644
--- a/src/include/utils/int8.h
+++ b/src/include/utils/int8.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: int8.h,v 1.14 1999/05/25 22:43:35 momjian Exp $
+ * $Id: int8.h,v 1.15 2000/01/10 16:13:22 momjian Exp $
  *
  * NOTES
  * These data types are supported on all 64-bit architectures, and may
@@ -92,7 +92,7 @@ extern int64 *int48(int32 val);
 extern int32 int84(int64 *val);
 
 #if NOT_USED
-extern int64 *int28 (int16 val);
+extern int64 *int2vector (int16 val);
 extern int16 int82(int64 *val);
 
 #endif
diff --git a/src/interfaces/odbc/convert.c b/src/interfaces/odbc/convert.c
index 09d27d3e04..a4f1487e86 100644
--- a/src/interfaces/odbc/convert.c
+++ b/src/interfaces/odbc/convert.c
@@ -209,7 +209,7 @@ char tempBuf[TEXT_FIELD_SIZE+5];
 		break;
 
 	/* This is for internal use by SQLStatistics() */
-	case PG_TYPE_INT28: {
+	case PG_TYPE_INT2VECTOR: {
 		// this is an array of eight integers
 		short *short_array = (short *) ( (char *) rgbValue + rgbValueOffset);
 
diff --git a/src/interfaces/odbc/pgtypes.h b/src/interfaces/odbc/pgtypes.h
index 3d97dec8c4..52b7a4a0c9 100644
--- a/src/interfaces/odbc/pgtypes.h
+++ b/src/interfaces/odbc/pgtypes.h
@@ -24,7 +24,7 @@
 #define PG_TYPE_NAME         19
 #define PG_TYPE_CHAR16       20
 #define PG_TYPE_INT2         21
-#define PG_TYPE_INT28        22
+#define PG_TYPE_INT2VECTOR   22
 #define PG_TYPE_INT4         23
 #define PG_TYPE_REGPROC      24
 #define PG_TYPE_TEXT         25
@@ -32,7 +32,7 @@
 #define PG_TYPE_TID          27
 #define PG_TYPE_XID          28
 #define PG_TYPE_CID          29
-#define PG_TYPE_OID8         30
+#define PG_TYPE_OIDVECTOR    30
 #define PG_TYPE_SET          32
 #define PG_TYPE_CHAR2       409
 #define PG_TYPE_CHAR4       410
diff --git a/src/backend/utils/adt/int.c b/src/backend/utils/adt/int.c
index 6c3c64c993..be791f49be 100644
--- a/src/backend/utils/adt/int.c
+++ b/src/backend/utils/adt/int.c
@@ -7,14 +7,14 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/int.c,v 1.30 2000/01/10 15:41:26 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/int.c,v 1.31 2000/01/10 16:13:14 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
 /*
  * OLD COMMENTS
  *		I/O routines:
- *		 int2in, int2out, int28in, int28out, int4in, int4out
+ *		 int2in, int2out, int2vectorin, int2vectorout, int4in, int4out
  *		Conversion routines:
  *		 itoi, int2_text, int4_text
  *		Boolean operators:
@@ -71,13 +71,13 @@ int2out(int16 sh)
 }
 
 /*
  *		int28in			- converts "num num ..." to internal form
  *
  *		Note:
  *				Fills any nonexistent digits with NULLs.
  */
 int16 *
-int28in(char *intString)
+int2vectorin(char *intString)
 {
 	int16	   *result;
 	int			slot;
@@ -99,7 +99,7 @@ int28in(char *intString)
 	while (*intString && isspace(*intString))
 		intString++;
 	if (*intString)
-		elog(ERROR,"int28 value has too many values");
+		elog(ERROR,"int2vector value has too many values");
 	while (slot < INDEX_MAX_KEYS)
 		result[slot++] = 0;
 
@@ -107,10 +107,10 @@ int28in(char *intString)
 }
 
 /*
  *		int28out		- converts internal form to "num num ..."
  */
 char *
-int28out(int16 *int2Array)
+int2vectorout(int16 *int2Array)
 {
 	int			num, maxnum;
 	char	   *rp;
@@ -130,7 +130,7 @@ int28out(int16 *int2Array)
 			break;
 
 	/* assumes sign, 5 digits, ' ' */
-	rp = result = (char *) palloc(maxnum * 7 + 1);
+	rp = result = (char *) palloc((maxnum+1) * 7 + 1);
 	for (num = 0; num <= maxnum; num++)
 	{
 		if (num != 0)
@@ -168,7 +168,7 @@ int44in(char *input_string)
 }
 
 /*
  *		int28out		- converts internal form to "num num ..."
  */
 char *
 int44out(int32 *an_array)
@@ -71,13 +71,13 @@ int2out(int16 sh)
 
 /*
- *		int28in			- converts "num num ..." to internal form
+ *		int2vectorin			- converts "num num ..." to internal form
  *
  *		Note:
@@ -107,10 +107,10 @@ int28in(char *intString)
 
 /*
- *		int28out		- converts internal form to "num num ..."
+ *		int2vectorout		- converts internal form to "num num ..."
  */
 char *
@@ -168,7 +168,7 @@ int44in(char *input_string)
 
 /*
- *		int28out		- converts internal form to "num num ..."
+ *		int2vectorout		- converts internal form to "num num ..."
  */
 char *
diff --git a/src/backend/utils/adt/oid.c b/src/backend/utils/adt/oid.c
index 989f4a602d..c8759db886 100644
--- a/src/backend/utils/adt/oid.c
+++ b/src/backend/utils/adt/oid.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/oid.c,v 1.31 2000/01/10 15:41:26 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/oid.c,v 1.32 2000/01/10 16:13:14 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -22,13 +22,13 @@
  *****************************************************************************/
 
 /*
  *		oid8in			- converts "num num ..." to internal form
  *
  *		Note:
  *				Fills any nonexistent digits with NULL oids.
  */
 Oid *
-oid8in(char *oidString)
+oidvectorin(char *oidString)
 {
 	Oid		   *result;
 	int			slot;
@@ -50,7 +50,7 @@ oid8in(char *oidString)
 	while (*oidString && isspace(*oidString))
 		oidString++;
 	if (*oidString)
-		elog(ERROR,"oid8 value has too many values");
+		elog(ERROR,"oidvector value has too many values");
 	while (slot < INDEX_MAX_KEYS)
 		result[slot++] = 0;
 
@@ -58,10 +58,10 @@ oid8in(char *oidString)
 }
 
 /*
  *		oid8out - converts internal form to "num num ..."
  */
 char *
-oid8out(Oid *oidArray)
+oidvectorout(Oid *oidArray)
 {
 	int			num, maxnum;
 	char	   *rp;
@@ -81,7 +81,7 @@ oid8out(Oid *oidArray)
 			break;
 
 	/* assumes sign, 10 digits, ' ' */
-	rp = result = (char *) palloc(maxnum * 12 + 1);
+	rp = result = (char *) palloc((maxnum+1) * 12 + 1);
 	for (num = 0; num <= maxnum; num++)
 	{
 		if (num != 0)
@@ -127,19 +127,19 @@ oidne(Oid arg1, Oid arg2)
 }
 
 bool
-oid8eq(Oid *arg1, Oid *arg2)
+oidvectoreq(Oid *arg1, Oid *arg2)
 {
 	return (bool) (memcmp(arg1, arg2, INDEX_MAX_KEYS * sizeof(Oid)) == 0);
 }
 
 bool
-oid8ne(Oid *arg1, Oid *arg2)
+oidvectorne(Oid *arg1, Oid *arg2)
 {
 	return (bool) (memcmp(arg1, arg2, INDEX_MAX_KEYS * sizeof(Oid)) != 0);
 }
 
 bool
-oid8lt(Oid *arg1, Oid *arg2)
+oidvectorlt(Oid *arg1, Oid *arg2)
 {
 	int			i;
 
@@ -150,7 +150,7 @@ oid8lt(Oid *arg1, Oid *arg2)
 }
 
 bool
-oid8le(Oid *arg1, Oid *arg2)
+oidvectorle(Oid *arg1, Oid *arg2)
 {
 	int			i;
 
@@ -161,7 +161,7 @@ oid8le(Oid *arg1, Oid *arg2)
 }
 
 bool
-oid8ge(Oid *arg1, Oid *arg2)
+oidvectorge(Oid *arg1, Oid *arg2)
 {
 	int			i;
 
@@ -172,7 +172,7 @@ oid8ge(Oid *arg1, Oid *arg2)
 }
 
 bool
-oid8gt(Oid *arg1, Oid *arg2)
+oidvectorgt(Oid *arg1, Oid *arg2)
 {
 	int			i;
 
@@ -22,13 +22,13 @@
 
 /*
- *		oid8in			- converts "num num ..." to internal form
+ *		oidvectorin			- converts "num num ..." to internal form
  *
  *		Note:
@@ -58,10 +58,10 @@ oid8in(char *oidString)
 
 /*
- *		oid8out - converts internal form to "num num ..."
+ *		oidvectorout - converts internal form to "num num ..."
  */
 char *
diff --git a/src/include/catalog/pg_type.h b/src/include/catalog/pg_type.h
index 1db7273c61..b3f9952bd5 100644
--- a/src/include/catalog/pg_type.h
+++ b/src/include/catalog/pg_type.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_type.h,v 1.72 1999/12/28 13:40:50 wieck Exp $
+ * $Id: pg_type.h,v 1.73 2000/01/10 16:13:21 momjian Exp $
  *
  * NOTES
  *	  the genbki.sh script reads this file and generates .bki
@@ -174,16 +174,16 @@ DATA(insert OID = 21 (	int2	   PGUID  2   5 t b t \054 0   0 int2in int2out int2
 DESCR("-32 thousand to 32 thousand, 2-byte storage");
 #define INT2OID			21
 
-DATA(insert OID = 22 (	int28	   PGUID 16  50 f b t \054 0  21 int28in int28out int28in int28out i _null_ ));
+DATA(insert OID = 22 (	int2vector PGUID 16  50 f b t \054 0  21 int2vectorin int2vectorout int2vectorin int2vectorout i _null_ ));
 DESCR("8 int2 integers, used internally");
 /*
  * XXX -- the implementation of int28's in postgres is a hack, and will
  *		  go away someday.	until that happens, there is a case (in the
  *		  catalog cache management code) where we need to step gingerly
  *		  over piles of int28's on the sidewalk.  in order to do so, we
  *		  need the OID of the int28 row from pg_type.
  */
-#define INT28OID		22
+#define INT2VECTOROID	22
 
 DATA(insert OID = 23 (	int4	   PGUID  4  10 t b t \054 0   0 int4in int4out int4in int4out i _null_ ));
 DESCR("-2 billion to 2 billion integer, 4-byte storage");
@@ -213,7 +213,7 @@ DATA(insert OID = 29 (	cid		   PGUID  4  10 t b t \054 0   0 cidin cidout cidin
 DESCR("command identifier type, sequence in transaction id");
 #define CIDOID 29
 
-DATA(insert OID = 30 (	oid8	   PGUID 32  89 f b t \054 0  26 oid8in oid8out oid8in oid8out i _null_ ));
+DATA(insert OID = 30 (	oidvector  PGUID 32  89 f b t \054 0  26 oidvectorin oidvectorout oidvectorin oidvectorout i _null_ ));
 DESCR("array of 8 oids, used in system tables");
 DATA(insert OID = 32 (	SET		   PGUID -1  -1 f b t \054 0   0 textin textout textin textout i _null_ ));
 DESCR("set of tuples");
@@ -317,7 +317,7 @@ DATA(insert OID = 1001 (  _bytea	 PGUID -1  -1 f b t \054 0	17 array_in array_ou
 DATA(insert OID = 1002 (  _char		 PGUID -1  -1 f b t \054 0	18 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1003 (  _name		 PGUID -1  -1 f b t \054 0	19 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1005 (  _int2		 PGUID -1  -1 f b t \054 0	21 array_in array_out array_in array_out i _null_ ));
-DATA(insert OID = 1006 (  _int28	 PGUID -1  -1 f b t \054 0	22 array_in array_out array_in array_out i _null_ ));
+DATA(insert OID = 1006 (  _int2vector PGUID -1  -1 f b t \054 0	22 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1007 (  _int4		 PGUID -1  -1 f b t \054 0	23 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1008 (  _regproc	 PGUID -1  -1 f b t \054 0	24 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1009 (  _text		 PGUID -1  -1 f b t \054 0	25 array_in array_out array_in array_out i _null_ ));
@@ -325,7 +325,7 @@ DATA(insert OID = 1028 (  _oid		 PGUID -1  -1 f b t \054 0	26 array_in array_out
 DATA(insert OID = 1010 (  _tid		 PGUID -1  -1 f b t \054 0	27 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1011 (  _xid		 PGUID -1  -1 f b t \054 0	28 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1012 (  _cid		 PGUID -1  -1 f b t \054 0	29 array_in array_out array_in array_out i _null_ ));
-DATA(insert OID = 1013 (  _oid8		 PGUID -1  -1 f b t \054 0	30 array_in array_out array_in array_out i _null_ ));
+DATA(insert OID = 1013 (  _oidvector PGUID -1  -1 f b t \054 0	30 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1014 (  _bpchar	 PGUID -1  -1 f b t \054 0 1042 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1015 (  _varchar	 PGUID -1  -1 f b t \054 0 1043 array_in array_out array_in array_out i _null_ ));
 DATA(insert OID = 1017 (  _point	 PGUID -1  -1 f b t \054 0 600 array_in array_out array_in array_out d _null_ ));
@@ -174,16 +174,16 @@ DATA(insert OID = 21 (	int2	   PGUID  2   5 t b t \054 0   0 int2in int2out int2
 DESCR("8 int2 integers, used internally");
 /*
- * XXX -- the implementation of int28's in postgres is a hack, and will
+ * XXX -- the implementation of int2vector's in postgres is a hack, and will
  *		  go away someday.	until that happens, there is a case (in the
  *		  catalog cache management code) where we need to step gingerly
@@ -174,16 +174,16 @@ DATA(insert OID = 21 (	int2	   PGUID  2   5 t b t \054 0   0 int2in int2out int2
  *		  go away someday.	until that happens, there is a case (in the
  *		  catalog cache management code) where we need to step gingerly
- *		  over piles of int28's on the sidewalk.  in order to do so, we
- *		  need the OID of the int28 row from pg_type.
+ *		  over piles of int2vector's on the sidewalk.  in order to do so, we
+ *		  need the OID of the int2vector row from pg_type.
  */